
module Corelight_Http_Downloader;

export {
	## Event that is called to start tracking a URL for a file download.
	## Will check file status each provided interval, and download a new version
	## if the server file is different.
	##
	## config: table[string] of string:
	##		"src":              URL to retrieve file from
	##		"dest":             Destination local file to write to
	##		"interval":         Interval between download checks
	global track_http_file: event(config: table[string] of string);

	## Event to call in order to halt tracking of a remote URL. Fetching will occur
	## indefinitely until this event is called.
	##
	## src:  URL the file is downloaded from
	global halt_track_http_file: event(src: string);

	## Event that is called when a URL tracking interval expires. 
	## Implement to handle a downloaded file.
	##
	## src:  URL the file is downloaded from
	## dest: Name of the downloaded file
	## is_changed: true if a new version of the file was downloaded. 
	global http_file_download_complete: event(src: string, dest: string, is_changed: bool);
}